#!/bin/sh

# EasyGPG-Installer 1.6
# Copyright (C) 2019 the author indicated below
# The author of EasyGPG-Installer made an OpenPGP,
# RSA key pair. The fingerprint of this key pair is
# BA34F30AC917CB0714884A3DA6BDBF5757B731E9
# EasyGPG-Installer is distributed under the terms of the GNU General
# Public License, version 3 (https://www.gnu.org/licenses/gpl.html).
# EasyGPG-Installer is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY--without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

missing=""
if ! which gpg > /dev/null
then
  missing="${missing}\ngpg (gnupg)"
fi
if ! which gpg-agent > /dev/null
then
  missing="${missing}\ngpg-agent (gnupg-agent)"
fi
if ! which zenity > /dev/null
then
  missing="${missing}\nzenity"
fi
if ! which xclip > /dev/null
then
  missing="${missing}\nxclip"
fi
if test -n "${missing}"
then
  errormsg="EasyGPG depends on the following software that is not installpath.\n${missing}\n\nPlease install the missing software and try again."
  if which zenity > /dev/null
  then
    zenity --error --width=400 --title "Missing Software" --text="${errormsg}" &
  elif which kdialog > /dev/null
  then
    kdialog --error "${errormsg}" --title "Missing Software" &
  elif which xmessage > /dev/null
  then
    printf "${errormsg}" | xmessage -center -buttons OK -default OK -xrm '*message.scrollVertical: Never' -file - &
  else
    printf "%s\n" "${errormsg}" 1>&2
  fi
  exit 1
fi

thisFile=`readlink -e "${0}"` # gets the absolute path name of this file
thisdir=`dirname "${thisFile}"`
cd "${thisdir}"
if lsof -ni | grep "TCP 127.0.0.1:4444 (LISTEN)" > /dev/null
then
  (wget -q -T 20 -t 4 -e use_proxy=yes -e http_proxy=127.0.0.1:4444 http://bwxry5alzx5ihgrd3glah4eotddblzhalvpheppnw4zcajzqoora.b32.i2p/easygpg-folder.asc) | zenity --progress --text="downloading the latest version of EasyGPG from easygpg2.i2p..." --pulsate --auto-close --no-cancel
  if ! test -f "easygpg-folder.asc"
  then
    if ! zenity --question --width=400 --title="Try archive.org?" --text="Couldn't read the latest version of EasyGPG from easygpg2.i2p.\nTry downloading from archive.org instead?" --ok-label="Try archive.org " --cancel-label="Cancel"
    then
      exit 0
    fi
  fi
fi
if ! test -f "easygpg-folder.asc"
then
  (wget -q -T 20 -t 4 https://archive.org/download/easygpg/easygpg-folder.asc) | zenity --progress --text="downloading the latest version of EasyGPG from archive.org..." --pulsate --auto-close --no-cancel
fi
if ! test -f "easygpg-folder.asc"
then
  zenity --info --width=400 --text="Download of EasyGPG failed." &
  rm -rf "${keydir}"
  exit 0
fi
keydir="${thisdir}/keyrings"
mkdir "${keydir}"
chmod 700 "${keydir}" # must be available only to you or won't be used
gpg --homedir "${keydir}" -k > /dev/null 2> /dev/null # initializes files in ${keydir}
keyStart=`cat "${thisFile}" | grep -n "^\-\-\-\-\-BEGIN PGP PUBLIC KEY BLOCK\-\-\-\-\-$" | grep -o "^[^:]*" | tail -n +1 | head -n 1`
signingKey=`tail -n +${keyStart} "${thisFile}"`
keyLength=`printf "%s\n" "${signingKey}" | grep -n "^\-\-\-\-\-END PGP PUBLIC KEY BLOCK\-\-\-\-\-$" | grep -o "^[^:]*" | head -n 1`
printf "%s\n" "${signingKey}" | head -n ${keyLength} | gpg --homedir "${keydir}" --import - 2> /dev/null
temp="${thisdir}/.$(cat /dev/urandom | tr -dc "0-9a-z" | head -c 10)"
gpg --homedir "${keydir}" --verify --status-file "${temp}" "easygpg-folder.asc" 2> /dev/null
if cat "${temp}" | grep "^\[GNUPG:\][\t ]*VALIDSIG" | grep "BA34F30AC917CB0714884A3DA6BDBF5757B731E9$" > /dev/null
then
  rm -f  "${temp}"
  gpg --homedir "${keydir}" -d "easygpg-folder.asc" 2> /dev/null | tar -x
  rm -rf "${keydir}"
  rm  "easygpg-folder.asc"
  egpgfolder="${thisdir}/easygpg"
  savepath="${HOME}/easygpg"
  savepath=`zenity --file-selection --save --directory --filename="${savepath}" --title="Save EasyGPG folder"`
  saveparent=`dirname "${savepath}"`
  if test -n "${savepath}"
  then
    installpath=""
    if test -f "${savepath}/easygpg.sh"
    then
      if zenity --question --width=400 --title="Replace with the latest EasyGPG?" --text="\"${savepath}\" already exists and contains EasyGPG.\nReplace with the latest EasyGPG?" --ok-label="Replace" --cancel-label="Cancel"
      then
        mv -f "${egpgfolder}/easygpg.sh" "${savepath}"
        mv -f "${egpgfolder}/set-up-easygpg.desktop" "${savepath}"
        installpath="${savepath}"
      fi
    elif test -f "${saveparent}/easygpg.sh"
    then
      if zenity --question --width=400 --title="Replace with the latest EasyGPG?" --text="\"${saveparent}\" already exists and contains EasyGPG.\nReplace with the latest EasyGPG?" --ok-label="Replace" --cancel-label="Cancel"
      then
        mv -f "${egpgfolder}/easygpg.sh" "${saveparent}"
        mv -f "${egpgfolder}/set-up-easygpg.desktop" "${saveparent}"
        installpath="${saveparent}"
      fi
      if test -e "${savepath}" && ! ls -A "${savepath}/"* > /dev/null 2> /dev/null
      then
        rm -rf "${savepath}"
      fi
    elif test -d "${savepath}" && ls -A "${savepath}/"* > /dev/null 2> /dev/null
    then
      zenity --info --width=400 --text="\"${savepath}\" already exists, and it is not an EasyGPG folder. You can not replace it." &
    elif test -f "${savepath}"
    then
      zenity --info --width=400 --text="\"${savepath}\" already exists, and it is not an EasyGPG folder. You can not replace it." &
    else
      mkdir "${savepath}"
      mv "${egpgfolder}/easygpg.sh" "${savepath}"
      mv "${egpgfolder}/set-up-easygpg.desktop" "${savepath}"
      installpath="${savepath}"
    fi
    if test -n "${installpath}"
    then
      if printf "%s\n" "${installpath}" | grep "^${HOME}" > /dev/null 2> /dev/null
      then
        thisrootdir="${HOME}"
      else
        thisrootdir=`printf "%s\n" "${installpath}" | grep -o "^/[^/]*"`
      fi
      if test -x "/usr/bin/tails-persistence-setup" || test "${thisrootdir}" = "/mnt" || test "${thisrootdir}" = "/media"
      then
        if test "${thisrootdir}" = "/mnt" || test "${thisrootdir}" = "/media"
        then
          tailsdir=`printf "/media/amnesia$(printf "${installpath}" | tail -c +$(dirname $(df --output=target ${installpath}) | tail -n 1 | wc -c))\n"`
        else
          tailsdir="${installpath}"
        fi
        tailspath="${installpath}/Tails Set Up.desktop"
        printf "%s\n" "#!/usr/bin/env xdg-open" > "${tailspath}"
        printf "\n" >> "${tailspath}"
        printf "%s\n" "[Desktop Entry]" >> "${tailspath}"
        printf "%s\n" "Type=Application" >> "${tailspath}"
        printf "%s\n" "Categories=Utility;Security;TextTools;" >> "${tailspath}"
        printf "%s\n" "Name=Tails Set Up" >> "${tailspath}"
        printf "%s\n" "Exec=${tailsdir}/easygpg.sh --su" >> "${tailspath}"
        printf "%s\n" "Icon=${tailsdir}/easygpgkeyrings/easygpg.png" >> "${tailspath}"
        chmod 700 "${tailspath}"
        printf "If this is Tails, copy or move \"Tails Set Up.desktop\" to the Desktop, right-click on it and Allow Launching, and then double-click it.\n" > "${installpath}/Tails-README"
        chmod 644 "${installpath}/Tails-README"
      fi
      xdg-open "${installpath}"
      sleep 2
      if test -x "/usr/bin/tails-persistence-setup"
      then
        zenity --info --width=400 --text="Copy or move \"Tails Set Up.desktop\" to the Desktop, right-click on it and Allow Launching, and then double-click it." &
      else
        zenity --info --width=400 --text="EasyGPG was successfully downloaded, verified, and installed.\nDouble-click \"Set Up EasyGPG\" and read the windows that pop up.\nYou are on your way to using EasyGPG." &
      fi
    fi
  fi
else
  rm -f  "${temp}"
  rm -rf "${keydir}"
  rm  "easygpg-folder.asc"
  zenity --info --width=400 --text="Verification of the signature on the download failed." &
fi
rm -rf "${egpgfolder}"


exit 0

# This is the public key of the key pair used to sign updates.
-----BEGIN PGP PUBLIC KEY BLOCK-----
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=yzOv
-----END PGP PUBLIC KEY BLOCK-----
